flux(data, local = names(data))data.
The default is to include all columns in the
calculations.ncol(data) rows and six columns:
pobs = Proportion observed, influx = Influx outflux =
Outflux ainb = Average inbound statistic aout = Averege
outbound statistic fico = Fraction of incomplete cases
among cases with Yj observed Influx is equal to the number of variable pairs (Yj
, Yk) with Yj missing and Yk observed,
divided by the total number of observed data cells.
Influx depends on the proportion of missing data of the
variable. Influx of a completely observed variable is
equal to 0, whereas for completely missing variables
wehave influx = 1. For two variables with the same
proportion of missing data, the variable with higher
influx is better connected to the observed data, and
might thus be easier to impute.
Outflux is equal to the number of variable pairs with
Yj observed and Yk missing, divided by the
total number of incomplete data cells. Outflux is an
indicator of the potential usefulness of Yj for
imputing other variables. Outflux depends on the
proportion of missing data of the variable. Outflux of a
completely observed variable is equal to 1, whereas
outflux of a completely missing variable is equal to 0.
For two variables having the same proportion of missing
data, the variable with higher outflux is better
connected to the missing data, and thus potentially more
useful for imputing other variables.
FICO is an outbound statistic defined by the fraction of
incomplete cases among cases with Yj observed
(White and Carlin, 2010).
White, I.R., Carlin, J.B. (2010). Bias and efficiency of multiple imputation compared with complete-case analysis for missing covariate values. Statistics in Medicine, 29, 2920-2931.
fluxplot, md.pattern,
fico