mice.impute.2lonly.mean(y, ry, x, type, ...)nFALSE=missing,
TRUE=observed)n x p) of complete covariates.ncol(x) identifying random and class
variables. The class variable (only one is allowed) is coded as '-2'.nmis with imputations.y are averaged within the class, and replicated to
the missing y within that class. If there are no observed data in the
class, all entries of the class are set to NaN. This function is
primarily useful for repairing incomplete data that are constant within the
class, but that vary over the classes.