Imputes univariate missing data using linear regression with boostrap
mice.impute.norm.boot(y, ry, x, wy = NULL, ridge = 1e-05, ...)Vector to be imputed
Logical vector of length length(y) indicating the
the subset y[ry] of elements in y to which the imputation
model is fitted. The ry generally distinguishes the observed
(TRUE) and missing values (FALSE) in y.
Numeric design matrix with length(y) rows with predictors for
y. Matrix x may have no missing values.
Logical vector of length length(y). A TRUE value
indicates locations in y for which imputations are created.
The ridge penalty used in .norm.draw() to prevent
problems with multicollinearity. The default is ridge = 1e-05,
which means that 0.01 percent of the diagonal is added to the cross-product.
Larger ridges may result in more biased estimates. For highly noisy data
(e.g. many junk variables), set ridge = 1e-06 or even lower to
reduce bias. For highly collinear data, set ridge = 1e-04 or higher.
Other named arguments.
Vector with imputed data, same type as y, and of length
sum(wy)
Draws a bootstrap sample from x[ry,] and y[ry], calculates
regression weights and imputes with normal residuals. The ridge
parameter adds a penalty term ridge*diag(xtx) to the
variance-covariance matrix xtx.
Van Buuren, S., Groothuis-Oudshoorn, K. (2011). mice:
Multivariate Imputation by Chained Equations in R. Journal of
Statistical Software, 45(3), 1-67.
http://www.jstatsoft.org/v45/i03/
Other univariate imputation functions: mice.impute.cart,
mice.impute.lda,
mice.impute.logreg.boot,
mice.impute.logreg,
mice.impute.mean,
mice.impute.midastouch,
mice.impute.norm.nob,
mice.impute.norm.predict,
mice.impute.norm,
mice.impute.pmm,
mice.impute.polr,
mice.impute.polyreg,
mice.impute.quadratic,
mice.impute.rf,
mice.impute.ri