mice.impute.passive(data, func)formula specifying the
transformations on dataformulamice Gibbs sampling algorithm, a
function on the imputed data. This is useful, for
example, to compute a cubic version of a variable, a
transformation like Q = W/H^2 based on two
variables, or a mean variable like
(x_1+x_2+x_3)/3. The so derived variables might be
used in other places in the imputation model. The
function allows to dynamically derive virtually any
function of the imputed data at virtually any time.mice: Multivariate Imputation by Chained Equations
in R. Journal of Statistical Software,
45(3), 1-67.
mice