mice.impute.pmm(y, ry, x, donors = 5, type = 1, ridge = 1e-05,
version = "", ...)y (TRUE=observed,
FALSE=missing)length(y) rows and p columns
containing complete covariates.donors = 5. Setting donors = 1 always selects the closest match. Values
between 3 and 10 provide the best results. Note: The default was changed from
3 to 5 intype = 1 calculates the distance between the predicted value of yobs and the drawn values of ymis. Other choices are type = 0 (distance between predicted val.norm.draw() to prevent problems with multicollinearity. The default is ridge = 1e-05, which means that 0.01 percent of the diagonal is added to the cross-product. Larger ridges may result in more biaversion = "2.21" calls .pmm.match() instead of the default
matcher() function.sum(!ry) with imputationsy by predictive mean matching, based on Rubin (1987, p.
168, formulas a and b). The procedure is as follows:
yobsbetaandymisbeta*ymis, finddonorsobservations with
closest predicted values, randomly sample one of these,
and take its observed value inyas the imputation.y, NOT on
observedy.Rubin, D.B. (1987). Multiple imputation for nonresponse in surveys. New York: Wiley.
Van Buuren, S., Brand, J.P.L., Groothuis-Oudshoorn C.G.M., Rubin, D.B. (2006) Fully conditional specification in multivariate imputation. Journal of Statistical Computation and Simulation, 76, 12, 1049--1064.
Van Buuren, S., Groothuis-Oudshoorn, K. (2011). mice: Multivariate
Imputation by Chained Equations in R. Journal of Statistical
Software, 45(3), 1-67.