mice.impute.pmm(y, ry, x)y (TRUE=observed, FALSE=missing)length(y) rows and p columns containing
complete covariatessum(!ry) with imputationsy by predictive mean matching, based on Rubin (1987, p. 168, formulas a and b).
The procedure is as follows:
yobsandymisymis, find the observation with closest predicted
value, and take its observed value inyas the imputation.y, NOT on observedy.