mice.impute.polyreg(y, ry, x, nnet.maxit = 100,
nnet.trace = FALSE, nnet.maxNWts = 1500, ...)nFALSE=missing, TRUE=observed)n x p) of complete
covariates.nnet().nnet().nnet().nmis with imputations.mice.impute.polyreg(). 'The
function mice.impute.polyreg() imputes categorical
response variables by the Bayesian polytomous regression
model. See J.P.L. Brand (1999), Chapter 4, Appendix B.The method consists of the following steps:
The algorithm of mice.impute.polyreg uses the
function multinom() from the nnet package.
In order to avoid bias due to perfect prediction, the algorithm augment the data according to the method of White, Daniel and Royston (2010).
mice: Multivariate Imputation by Chained Equations
in R. Journal of Statistical Software,
45(3), 1-67.
Brand, J.P.L. (1999) Development, implementation and evaluation of multiple imputation strategies for the statistical analysis of incomplete data sets. Dissertation. Rotterdam: Erasmus University.
White, I.R., Daniel, R. Royston, P. (2010). Avoiding bias due to perfect prediction in multiple imputation of incomplete categorical variables. Computational Statistics and Data Analysis, 54, 2267-2275.
Venables, W.N. & Ripley, B.D. (2002). Modern applied statistics with S-Plus (4th ed). Springer, Berlin.
mice, multinom,
polr