mira object is generated by the with.mids(), lm.mids() and glm.mids()
functions.
The mira class of objects has methods for the following generic functions:
print, summary.is.mira(x)
## S3 method for class 'mira':
print(x)
## S3 method for class 'mira':
summary(object)m fit objects of a complete data analysis,
plus some additional information.mids object that was used in call.m components containing the individual fit objects from each of the m complete data analyses.with.mids, mids, mipo