mira-class: Multiply imputed repeated analyses (mira)
Description
The mira object is generated by the
with.mids() function. The as.mira() function
takes the results of repeated complete-data analysis stored
as a list, and turns it into a mira object that can
be pooled. Pooling requires that coef() and
vcov() methods are available for fitted object. The
mira class of objects has methods for the following
generic functions: print, summary.References
van Buuren S and Groothuis-Oudshoorn K (2011). mice:
Multivariate Imputation by Chained Equations in R.
Journal of Statistical Software, 45(3), 1-67.
http://www.jstatsoft.org/v45/i03/